tlslite.errors.TLSAuthorizationError

Package tlslite :: Module errors :: Class TLSAuthorizationError |
[hide private]
[frames] | no frames]

# Class TLSAuthorizationError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                            TLSError --+
                                       |
                  TLSAuthenticationError --+
                                           |
                                          TLSAuthorizationError

The Checker was expecting the other party to authenticate with a certificate chain that has a different authorization.

Instance Methods | [hide private]
Inherited from `TLSError`: `__str__` Inherited from `exceptions.Exception`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`